@@ -107,6 +107,10 @@ class ProgressStateMachine:
 
         parsed_response = self.parser.parse(response)
 
+        if parsed_response == 'JSONDecodeError':
+            logger.info(f'The service chain uuid associated with this workflow is: {self.service_chain_uuid}')
+            exit('')
+
         return parsed_response.chain_links[self.chain_link]
 
     def parse_status_updates(self, updates):
